#! /bin/sh
#=======================================================================
# This script attempts to build and check a program on every UNIX C
# and C++ compiler available to the author.
#
# Because of wide variations in optimizer switches, no attempt is yet
# made to validate the same compiler at multiple optimization levels:
# that job is left for the installer.
#
# Usage:
#	build-on-one-machine.sh [PROGRAM] |& tee -a typescript.xxx
#
# The program author can examine the output in the typescript.xxx file
# to determine what, if any, changes are needed in the code to ensure
# that it will build correctly.
#
# [08-Jul-1998] -- Add command-line PROGRAM option
# [15-Jun-1998]
#=======================================================================

if test $# -eq 1
then
	PROGRAM=$1
	export PROGRAM
fi

# Here is a list of known compilers on DEC (MIPS ULTRIX and Alpha
# OSF/1), HP (PA-RISC HP-UX), IBM (POWER AIX), IBM PC (Intel LINUX),
# NeXT (Motorola 68K Mach) SGI (MIPS), and Sun (SPARC SunOS and SPARC
# Solaris) systems.  We try all that actually exist on this system.

./doconfig.sh /bin/CC
./doconfig.sh /bin/c89
./doconfig.sh /bin/cc
./doconfig.sh /bin/cxx			"-x cxx"
./doconfig.sh /bin/xlC
./doconfig.sh /opt/SUNWspro/bin/CC
./doconfig.sh /opt/SUNWspro/bin/c89
./doconfig.sh /opt/SUNWspro/bin/cc
./doconfig.sh /usr/bin/CC
./doconfig.sh /usr/bin/DCC
./doconfig.sh /usr/bin/NCC
./doconfig.sh /usr/bin/c89
./doconfig.sh /usr/bin/cc
./doconfig.sh /usr/bin/g++
./doconfig.sh /usr/bin/gcc
./doconfig.sh /usr/bin/ncc
./doconfig.sh /usr/ccs/bin/c89
./doconfig.sh /usr/ccs/bin/cc
./doconfig.sh /usr/lang/CC
./doconfig.sh /usr/lang/acc
./doconfig.sh /usr/local/bin/g++
./doconfig.sh /usr/local/bin/gcc
./doconfig.sh /usr/local/bin/lcc	"-A -A"
./doconfig.sh /usr/ucb/cc

if test "xx`uname -s`" = "xxIRIX" -a "xx`uname -r`" = "xx6.3"
then
	./doconfig.sh /bin/DCC			"-n32"
	./doconfig.sh /bin/NCC			"-n32"
	./doconfig.sh /bin/cc			"-n32"
	./doconfig.sh /usr/bin/DCC		"-n32"
	./doconfig.sh /usr/bin/NCC		"-n32"
	./doconfig.sh /usr/bin/cc		"-n32"

	./doconfig.sh /bin/DCC			"-32"
	./doconfig.sh /bin/NCC			"-32"
	./doconfig.sh /bin/cc			"-32"
	./doconfig.sh /usr/bin/DCC		"-32"
	./doconfig.sh /usr/bin/NCC		"-32"
	./doconfig.sh /usr/bin/cc		"-32"

	./doconfig.sh /bin/DCC			"-64"
	./doconfig.sh /bin/NCC			"-64"
	./doconfig.sh /bin/cc			"-64"
	./doconfig.sh /usr/bin/DCC		"-64"
	./doconfig.sh /usr/bin/NCC		"-64"
	./doconfig.sh /usr/bin/cc		"-64"
fi
    
if test "xx`uname -s`" = "xxIRIX64" -a "xx`uname -r`" = "xx6.4"
then
	./doconfig.sh /bin/DCC			"-n32"
	./doconfig.sh /bin/NCC			"-n32"
	./doconfig.sh /bin/cc			"-n32"
	./doconfig.sh /usr/bin/DCC		"-n32"
	./doconfig.sh /usr/bin/NCC		"-n32"
	./doconfig.sh /usr/bin/cc		"-n32"

	./doconfig.sh /bin/DCC			"-32"
	./doconfig.sh /bin/NCC			"-32"
	./doconfig.sh /bin/cc			"-32"
	./doconfig.sh /usr/bin/DCC		"-32"
	./doconfig.sh /usr/bin/NCC		"-32"
	./doconfig.sh /usr/bin/cc		"-32"

	./doconfig.sh /bin/DCC			"-64"
	./doconfig.sh /bin/NCC			"-64"
	./doconfig.sh /bin/cc			"-64"
	./doconfig.sh /usr/bin/DCC		"-64"
	./doconfig.sh /usr/bin/NCC		"-64"
	./doconfig.sh /usr/bin/cc		"-64"
fi

echo ================================= Done =================================
